@@ -1,10 +1,8 @@
 import numpy as np
-from typing import List
 import re
 import matplotlib.pyplot as plt
 from variable_lib_drturtle.variables import *
 from dataclasses import dataclass
-from typing import Any, List
 
 U_RE = re.compile(r"^(?P<name>.+?)(?:\((?P<unit>.+)\))?$", flags=re.MULTILINE)
 
@@ -18,7 +16,6 @@ class Value1D:
 
     name: str
     unit: str
-    value: Any
     values: np.ndarray
 
     @property
@@ -37,6 +34,11 @@ class Value1D:
         """
         return f"{self.name}: {self.with_unit}"
 
+    @property
+    def value(self):
+        """Returns the most recent value"""
+        return self.values[-1]
+
     def __getitem__(self, key: int):
         return self.values[key]
 
@@ -146,11 +148,11 @@ class VariableList2D:
 
     @property
     def x(self):
-        return Value1D(f"X {self.name}", self.unit, self.x_values[-1], self.x_values)
+        return Value1D(f"X {self.name}", self.unit, self.x_values)
 
     @property
     def y(self):
-        return Value1D(f"Y {self.name}", self.unit, self.y_values[-1], self.y_values)
+        return Value1D(f"Y {self.name}", self.unit, self.y_values)
 
     @property
     def magnitude(self):
@@ -166,6 +168,7 @@ class VariableList2D:
 
 
 def scatter_2d(x_list, y_list, do_x=False):
+    """Deprecated"""
     if isinstance(x_list, VariableList):
         x_name = x_list.name
         x_vals = x_list
